==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/nl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Onbekend adres",
    "No result." : "Geen resultaat.",
    "Malformed JSON data." : "Onjuist opgemaakte JSON-gegevens.",
    "Error" : "Fout",
    "Weather status" : "Weerstatus",
    "Weather status in your dashboard" : "Weerstatus in uw dashboard",
    "Detect location" : "Locatie detecteren",
    "Set custom address" : "Aangepast adres instellen",
    "Favorites" : "Favorieten",
    "{temperature} {unit} Clear sky at {time}" : "{temperature}{unit} Onbewolkt om {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewolkt om {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Redelijk dag om {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Redelijk nacht om {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Half bewolkt om {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mist om {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} lichte regen om {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen om {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Zware regen om {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenbuien om {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lichte regenbuien om {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Hevige regenbuien om {time}",
    "More weather for {adr}" : "Meer weer voor {adr}",
    "Loading weather" : "Weergegevens ophalen",
    "Set location for weather" : "Stel je locatie voor het weer in.",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "There was an error getting the weather status information." : "Er is een fout opgetreden bij het ophalen van de weerinformatie.",
    "No weather information found" : "Geen weer informatie gevonden.",
    "Location not found" : "Locatie niet gevonden",
    "There was an error setting the location address." : "Er is een fout opgetreden bij het zetten van het locatie adres.",
    "There was an error setting the location." : "Er is een fout opgetreden bij het vastleggen van de locatie.",
    "There was an error saving the mode." : "Er was een fout in het vastleggen van de modus.",
    "There was an error using personal address." : "Er was een fout bij het gebruiken van je persoonlijke adres.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weersverwachting is geïntegreerd in de dashboard app\nDe gebruikers locatie kan automatisch worden bepaald of handmatig worden ingegeven. Een 6 uurs weersverwachting wordt getoond.\nDeze Weersverwachting kan ook op andere plaatsen worden geïntegreerd zoals in de Kalender-app."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/nl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Onbekend adres",
    "No result." : "Geen resultaat.",
    "Malformed JSON data." : "Onjuist opgemaakte JSON-gegevens.",
    "Error" : "Fout",
    "Weather status" : "Weerstatus",
    "Weather status in your dashboard" : "Weerstatus in uw dashboard",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weerbericht is geïntegreerd in de dashboard app\nDe gebruikerslocatie kan automatisch worden bepaald of handmatig worden ingegeven. Een 6 uurs weersverwachting wordt getoond.\nDeze status kan ook op andere plaatsen worden geïntegreerd zoals in de Kalender-app.",
    "Detect location" : "Locatie detecteren",
    "Set custom address" : "Aangepast adres instellen",
    "Favorites" : "Favorieten",
    "{temperature} {unit} Clear sky at {time}" : "{temperature}{unit} Onbewolkt om {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Bewolkt om {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Redelijk dag om {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Redelijk nacht om {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Half bewolkt om {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mist om {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} lichte regen om {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Regen om {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Zware regen om {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Regenbuien om {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lichte regenbuien om {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Hevige regenbuien om {time}",
    "More weather for {adr}" : "Meer weer voor {adr}",
    "Loading weather" : "Weergegevens ophalen",
    "Set location for weather" : "Stel je locatie voor het weer in.",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "You are not logged in." : "Je bent niet ingelogd.",
    "There was an error getting the weather status information." : "Er is een fout opgetreden bij het ophalen van de weerinformatie.",
    "No weather information found" : "Geen weer informatie gevonden.",
    "Location not found" : "Locatie niet gevonden",
    "There was an error setting the location address." : "Er is een fout opgetreden bij het zetten van het locatie adres.",
    "There was an error setting the location." : "Er is een fout opgetreden bij het vastleggen van de locatie.",
    "There was an error saving the mode." : "Er was een fout in het vastleggen van de modus.",
    "There was an error using personal address." : "Er was een fout bij het gebruiken van je persoonlijke adres.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Weersverwachting is geïntegreerd in de dashboard app\nDe gebruikers locatie kan automatisch worden bepaald of handmatig worden ingegeven. Een 6 uurs weersverwachting wordt getoond.\nDeze Weersverwachting kan ook op andere plaatsen worden geïntegreerd zoals in de Kalender-app."
},
"nplurals=2; plural=(n != 1);");
